@@ -1,22 +1,8 @@
-/****************************************************************************
-Copyright 2016  Oleg Chernovskiy <kanedias@xaker.ru>
+/*
+    SPDX-FileCopyrightText: 2016 Oleg Chernovskiy <kanedias@xaker.ru>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-****************************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "remote_access.h"
 #include "event_queue.h"
 #include "wayland_pointer_p.h"
@@ -64,7 +50,7 @@ void RemoteAccessManager::Private::bufferReadyCallback(void *data, org_kde_kwin_
     rbuf->setup(requested);
     qCDebug(KWAYLAND_CLIENT) << "Got buffer, server fd:" << buffer_id;
 
-    emit ramp->q->bufferReady(output, rbuf);
+    Q_EMIT ramp->q->bufferReady(output, rbuf);
 }
 
 void RemoteAccessManager::Private::setup(org_kde_kwin_remote_access_manager *k)
@@ -136,7 +122,7 @@ public:
 
     WaylandPointer<org_kde_kwin_remote_buffer, org_kde_kwin_remote_buffer_release> remotebuffer;
     RemoteBuffer *q;
-    
+
     qint32 fd = 0;
     quint32 width = 0;
     quint32 height = 0;
@@ -159,7 +145,7 @@ void RemoteBuffer::Private::paramsCallback(void *data, org_kde_kwin_remote_buffe
     p->height = height;
     p->stride = stride;
     p->format = format;
-    emit p->q->parametersObtained();
+    Q_EMIT p->q->parametersObtained();
 }
 
 #ifndef K_DOXYGEN
